/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/25 09:42:10 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/paragui.h,v $
    CVS/RCS Revision: $Revision: 1.38 $
    Status:           $State: Exp $
*/

/*! \mainpage ParaGUI Documentation

	\section intro Introduction
	ParaGUI is a cross-platform high-level application framework and GUI (graphical user interface) library.<br>
	It can be compiled on various platforms (Linux, Win32, BeOS, MacOS, ...)<br><br>
	ParaGUI is completely based on the Simple DirectMedia Layer (SDL).<br>
	
	\section highlights Highlights of the library
	
	published under LGPL<br>
	straight forward C++ class-design (see the API documentation)<br>
	asynchronous messagehandling (messageposts between objects)<br>
	multithreaded<br>
	highly customizable widgets<br>
	(background gradients, background images, transparency, colors, fonts)<br>
	many standard widgets already implemented<br>
	(buttons, labels, scrollbars, progressbars, windows ...)<br>
	create your own widgets<br>
	(subclass an existing widget) <br>


	\section install Installation
	
	\subsection step1 Installing from RPM
	That's the easiest method:
			
	rpm -Uhv paragui-x.x.x.rpm<br>
	rpm -Uhv paragui-devel-x.x.x.rpm<br>
			
	and you're set.

	\subsection step2 Installing from a tarball
	A bit more work but also quite easy:
			
	tar -zxvf paragui-x.x.x.tar.gz<br>
	cd paragui-x.x.x<br>
	./configure [--prefix=/usr]<br>
	make<br>
	make install [as root]
			
*/

/**	\page coding Coding conventions for ParaGUI
<body>

<h2>The Easy Route</h2>

<p>
Grab astyle, a code formatter for C, C++, and Java, from
<a href="http://astyle.sourceforge.net">
http://astyle.sourceforge.net</a>.
All code in the repository should be run through astyle
before being committed, with these options:
</p>
<pre>astyle --style=kr --indent=tab <filename></pre>
<p>Or, to make life easy, you can put <a href="./astylerc">
this file</a> in ~/.astylerc and just run: </p>
<pre>astyle <filename></pre>

<p>Doing this has several advantages:</p>
<ul>
	<li>Code in the repository will be consistently
	    formatted.</li>
	<li>You don't have to worry about the coding
	    conventions while coding, or at all for that
	    matter.</li>
	<li>You can reformat code to your own personal
	    style preference while working on it, and
	    then easily convert it back to the way it was,
	    along with your added code.  Since astyle will
	    format it in the exact same way, patches won't
	    be filled with many lines of useless formatting
	    changes.</li>
	<li>It's easy ;).</li>
</ul>

<p>Note: don't make a habit of formatting all source files
("just to be sure") instead of just the ones you modified.
This will update the timestamps on the files and cause all
hell to break loose.</p>

<p>Here's an outline of the code format, for the sake of
completeness.. but use astyle. Please. :)</p>

<h2>Sample code:</h2>

<pre>
// No, this code is not supposed to make sense
void foo(int bar) {
	if (bar < 7) {
		cout << bar << endl;
	}
	else {
		cout << "That's a big bar you got there.\n"
	}
}
</pre>

<h2>Things to notice:</h2>

<ul>
	<li>C++ (//) style comments are best for few-line comments</li>
	<li>Use C comments for commenting large blocks</li>
	<li>K&R style braces, with one space before the first brace</li>
	<li>No spaces padding the inside of parenthesis</li>
	<li>One space padding of operators on both sides</li>
	<li>An if statement's block will always be enclosed in braces,
	    even if it is just one line.</li>
	<li>Hard tabs for indents</li>
	<li>And the most important thing of all, no matter what you do:
	  <b>Do not assume anything about the length of a tab.</b>
	  This means don't mix tabs and spaces in an interchangeable way.
	  This way, everything that looks nice in an editor with 8-space
	  tabs, will look just fine in an editor with 4-space tabs, etc.
	</li>
</ul>

</body>
*/

/**	\page requirements	Requirements for compiling ParaGUI

	ParaGUI is completely based on SDL from Sam Lantinga. <br>
	You have to checkout the following libs from his <a href="http://www.libsdl.org">website</a>: <p>

	<b>ParaGUI Version <= 0.5.2: </b><p>

	SDL (Simple Directmedia Layer) Version <= 1.1.4 <br>
	SDL_ttf (True Type Font Rendering Engine for SDL) Version <= 1.2.1 <br>
	FreeType >= 1.2.0 <p>

	<b>ParaGUI Version >= 0.5.3: </b><p>

	SDL (Simple Directmedia Layer) Version >= 1.1.5 <br>
	or the latest snapshot from his CVS repository <br>
	SDL_ttf (True Type Font Rendering Engine for SDL) Version >= 1.2.2 <br>
	FreeType >= 1.2.0<br>
*/

/**	\page	contribute	Contributing (A small CVS guide)

<br>
<ol>
<li>Download the sourcetree via CVS<br>
<br>
<i>cvs -d :pserver:guest@www.bms-austria.com:/usr/local/CVSROOT login<br>
password: guest<br>
<br>
cvs -d :pserver:guest@www.bms-austria.com:/usr/local/CVSROOT -z3 checkout paragui<br>
<br>
sh autogen.sh<br>
./configure [--prefix=/usr]<br>
make<br>
make install (as root)<br>
<br><br>
</i>
<li>Make your changes<br>
<br>
<li>Sync with the repository<br>
<br>
<i>cvs -z3 update -d -P<br>
</i>
<br><br>
<li>Create a patchfile<br>
<br>
<i>cvs diff -c3p<br>
</i>
<br><br>
<li>Send the patchfile via email to <a href="mailto:pipelka@bms-austria.com">me</a><br>
Please give a short (or even longer) description what the patch exactly does.<br>
<br><br>
</ol>
*/

/**	\example tut1.cpp		TUTORIAL 1 - application initialization, eventloop
*/

/**	\example tut2.cpp		TUTORIAL 2 - our first widget (a button)
*/

/**	\example tut3.cpp		TUTORIAL 3 - callback functions
*/

/**	\example tut4.cpp		TUTORIAL 4 - custom widgets
*/


#ifndef PARAGUI_H
#define PARAGUI_H

#ifdef SWIG
%include "swigcommon.h"
%module paragui
%{
#include "paragui.h"
%}
%include "paragui_types.h"
%include "sdlmessageobject.h"
%include "sdldrawobject.h"
%include "sdlwidget.h"
%include "sdlwidgetdnd.h"
%include "sdlgradientwidget.h"
%include "sdlwidgetlist.h"
%include "sdlapplication.h"
%include "sdlbutton.h"
%include "sdlbuttongroup.h"
%include "sdlradiobutton.h"
%include "sdlcheckbutton.h"
%include "sdllabel.h"
%include "sdllineedit.h"
%include "sdlscrollbar.h"
%include "sdlprogressbar.h"
%include "sdlstaticframe.h"
%include "sdlwindow.h"
%include "sdlslider.h"
%include "sdllistboxitem.h"
%include "sdlcolumnitem.h"
%include "sdllistbox.h"
#endif

#include <stdlib.h>

// SDL
#include <SDL.h>
#include <SDL_ttf.h>
#include <SDL_thread.h>

#include "paragui_types.h"
#include "theme.h"

#define DISPLAY_DEPTH 16

// Background modes

#define BKMODE_TILE			1
#define BKMODE_STRETCH		2


// Button states

#define BTN_STATE_NORMAL		0
#define BTN_STATE_PRESSED		1
#define BTN_STATE_HIGH			2


// Text alignment

#define SDL_TA_LEFT		0
#define SDL_TA_CENTER	1
#define SDL_TA_RIGHT	2


// Scrollbars

#define SDL_SB_VERTICAL		1
#define SDL_SB_HORIZONTAL	2

// internal widget ids

#define	SDL_WIDGETID_INTERNAL	10000

// Scrollbar up,down,dragbutton

#define SDL_IDSCROLLBAR_UP		SDL_WIDGETID_INTERNAL + 1
#define SDL_IDSCROLLBAR_DOWN	SDL_WIDGETID_INTERNAL + 2
#define SDL_IDSCROLLBAR_LEFT	SDL_WIDGETID_INTERNAL + 3
#define SDL_IDSCROLLBAR_RIGHT	SDL_WIDGETID_INTERNAL + 4
#define SDL_IDSCROLLBAR_DRAG	SDL_WIDGETID_INTERNAL + 5

// WidgetList scrollbar
#define SDL_IDWIDGETLIST_SCROLL	SDL_WIDGETID_INTERNAL + 10

// SDLApplication object
#define SDL_IDAPPLICATION	SDL_WIDGETID_INTERNAL + 100

#endif // PARAGUI_H
