/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/25 14:01:33 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdlbutton.h,v $
    CVS/RCS Revision: $Revision: 1.30 $
    Status:           $State: Exp $
*/

#ifndef SDLBUTTON_H
#define SDLBUTTON_H

#ifdef SWIG
%include "swigcommon.h"
%module sdlbutton
%{
#include "sdlbutton.h"
%}
#endif

#include "sdlwidget.h"

/**
	@author Alexander Pipelka

	@short Button with hardcoded colors and gradients, with text or icon.

	This should be integrated with SDLButton once the themeing takes place
	as this current buttom system is a little odd.
*/

class DECLSPEC SDLUserButton : public SDLWidget {
public:

	SDLUserButton(SDLWidget* parent, int btnid, SDL_Rect& r, char* text = NULL);
	virtual ~SDLUserButton();

	/**  */
	void DrawBorder(int size=2);
	
	/**  */
#ifndef SWIG
	/** SWIG has problems with this, for some reason..  (?) */
	bool SetIcon(char* filenameup, char* filenamedown = NULL, Uint32 colorkey = 0x000000FF);
#endif
	
	/**  */
#ifdef SWIG
	/** SWIG can't handle multiple functions with one name */
	%name(SetIcon2) bool SetIcon(SDL_Surface* icon_up, SDL_Surface* icon_down = NULL);
#else
	bool SetIcon(SDL_Surface* icon_up, SDL_Surface* icon_down = NULL);
#endif
	
	/**  */
	void SetBorderSize(int norm, int pressed, int high);
	
	/**  */
	void SetToggle(bool bToggle);
	
	/**  */
	void SetPressed(bool pressed);
	
	/**  */
	void SetTransparency(int norm, int pressed, int high);
	
	/**  */
	void SetText(char* text);

	/**  */
	char* GetText();
	
	/**  */
	bool GetPressed();

protected:

	/**  */
	void eventDraw(SDL_Surface* surface, SDL_Rect* rect);

	/**  */
	void eventSizeWindow(int w, int h);

	/**  */
	void eventMouseLeave();

	/**  */
	void eventMouseEnter();

	/**  */
	bool eventMouseButtonUp(const SDL_MouseButtonEvent* button);

	/**  */
	bool eventMouseButtonDown(const SDL_MouseButtonEvent* button);

	/**  */
	virtual void OnButtonSurface(SDL_Surface** surface, int newstate, int w, int h);

	int bordersize[3];
	int transparency[3];
	int state;
	int id;
	int my_pressShift;

private:
	SDLUserButton(const SDLUserButton&);
	SDLUserButton& operator=(const SDLUserButton&);
	
	/**  */
	void FreeSurfaces();

	/**  */
	void FreeIcons();

	SDL_Surface* srf_normal;
	SDL_Surface* srf_high;
	SDL_Surface* srf_down;
	SDL_Surface* srf_icon[2];

	char labeltext[255];
	bool free_icons;
	
	bool isPressed;
	bool togglemode;
};

/**
	@author Alexander Pipelka

	@short Button that uses gradients, all else derived from SDLUserButton

	This should be integrated with SDLUserButton once the themeing engine
	is implemented, this is very unclear at the moment.
*/

class DECLSPEC SDLButton : public SDLUserButton  {
public:

	/**  */
	SDLButton(SDLWidget* parent, int id, SDL_Rect& r, char* text = NULL);

	/**  */
	virtual ~SDLButton();

	/**  */
	void LoadThemeStyle(const char* widgettype);

	/**  */
	void LoadThemeStyle(const char* widgettype, const char* objectname);

	/**  */
	void SetGradient(int state, SDL_Gradient& gradient);

	/**  */
	void SetBackground(int state, SDL_Surface* background, int mode = BKMODE_TILE);
	
protected:

	/**  */
	void OnButtonSurface(SDL_Surface** surface, int newstate, int w, int h);

private:
	SDLButton(const SDLButton&);
	SDLButton& operator=(const SDLButton&);

	SDL_Gradient my_gradState[3];
	SDL_Surface* my_background[3];
	int my_backMode[3];
	int my_backBlend[3];
};

#endif // SDLBUTTON_H
