/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/17 18:22:46 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdlgradientwidget.h,v $
    CVS/RCS Revision: $Revision: 1.27 $
    Status:           $State: Exp $
*/

#ifndef SDLGRADIENTWIDGET_H
#define SDLGRADIENTWIDGET_H

#ifdef SWIG
%include "swigcommon.h"
%module sdlgradientwidget
%{
#include "sdlgradientwidget.h"
%}
#endif

#include "sdlwidgetdnd.h"

/**
	@author Alexander Pipelka

	@short Base class for widgets with gradients.

	Objects that want to be pretty derive from this.
*/

class DECLSPEC SDLGradientWidget : public SDLWidgetDnD  {
public:

	SDLGradientWidget(SDLWidget* parent, SDL_Rect& r);
	~SDLGradientWidget();

	void LoadThemeStyle(const char* widgettype);

	void LoadThemeStyle(const char* widgettype, const char* objectname);
	
	/**
	Load the background image from a file
	*/
	bool SetBackground(const char* filename, int mode=BKMODE_TILE);

	/**
	Define a surface as background image (will not be freed)
	*/
#ifdef SWIG
	%name(SetBackground2) bool SetBackground(SDL_Surface* surface, int mode=BKMODE_TILE);
#else
	bool SetBackground(SDL_Surface* surface, int mode=BKMODE_TILE);
#endif

	/**
	Defines the "blend-level" of gradient & background
	*/
	void SetBackgroundBlend(Uint8 backblend);

	/**
	Set the background gradient
	*/

	void SetGradient(SDL_Gradient& grad);

protected:

	/**  */
	void eventDraw(SDL_Surface* surface, SDL_Rect* rect);

	SDL_Gradient my_gradient;
	SDL_Surface* my_background;

	Uint8 my_blendLevel;
	bool my_backgroundFree;
	int my_backgroundMode;
	int my_bordersize;

private:

	SDLGradientWidget(const SDLGradientWidget&);
	SDLGradientWidget& operator=(const SDLGradientWidget&);

	/**
	This function frees background surface when possible
	*/
	void FreeSurface();
};

#endif // SDLGRADIENTWIDGET_H
