/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/19 11:57:41 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdllabel.h,v $
    CVS/RCS Revision: $Revision: 1.27 $
    Status:           $State: Exp $
*/

#ifndef SDLLABEL_H
#define SDLLABEL_H

#ifdef SWIG
%include "swigcommon.h"
%module sdllabel
%{
#include "sdllabel.h"
%}
#endif

#include "sdlwidget.h"
#include "sdlapplication.h"

/**
	@author Alexander Pipelka
 
	@short Text label.
 
	A text label (unmodifiable by end user).  Has attributes for font style,
	alignment, etc.
*/

class DECLSPEC SDLLabel : public SDLWidget {
public:

	/** Only constructor
	@param parent			Parent widget.
	@param r				Rectangle to draw in, relative to parent.
	@param text				Text displayed by label.
	@param storebackground	Whether or not label has an internal background.
	*/
	SDLLabel(SDLWidget* parent, SDL_Rect& r, char* text, bool storebackground = true);

	/** Only destructor */
	~SDLLabel();

	/** Sets text */
	void SetText(char* text);

#ifndef SWIG
	/** Sets formated text (like printf)*/
	void SetTextFormat(char* text, ...);
#endif

	/** Returns text */
	char* GetText();

	/** Sets text alignment */
	void SetAlignment(int a);

	/** */
	static void GetTextExtend(char* text, int& width, int &height, TTF_Font* font = NULL);
	
	/** */
	void GetTextExtend(char* text, int& width, int &height);

	/** */
	SDL_Surface* SetIcon(char* filename);

	/** */
	SDL_Surface* SetIcon(SDL_Surface* icon);

protected:

	/** Draw event handler
	@param SDL_Surface	Surface to draw to.
	@param rect			Rectangle to draw in, relative to surface.
	*/
	void eventDraw(SDL_Surface* surface, SDL_Rect* rect);

	/** */
	void eventBlit(SDL_Surface* srf, SDL_Rect* src, SDL_Rect* dst);

	SDL_Surface* my_srfIcon;

private:

	SDLLabel(const SDLLabel&);
	SDLLabel& operator=(const SDLLabel&);

	bool my_freeIcon;
	int my_alignment;
	char* my_textLabel;
	SDL_Rect my_rectLabel;
	SDL_Surface* my_srfText;
};

#endif // SDLLABEL_H
