/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/26 13:35:04 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdllineedit.h,v $
    CVS/RCS Revision: $Revision: 1.24 $
    Status:           $State: Exp $
*/

#ifndef SDL_LINEEDIT
#define SDL_LINEEDIT

#ifdef SWIG
%include "swigcommon.h"
%module sdllineedit
%{
#include "sdllineedit.h"
%}
#endif

#include "sdlgradientwidget.h"

/**
	@author Alexander Pipelka

	@short An editable text box.

	This really should be renamed to SDLTextBox or something similar, because
	SDLLineEdit really makes no sense :).  Also the 'Edit' part implies that
	it will always be modifiable, but having a modifyable attribute would
	probably be better than creating a whole new widget for an unmodifiable
	text box.
*/
class DECLSPEC SDLLineEdit : public SDLGradientWidget {
public:

	/** */
	SDLLineEdit(SDLWidget* parent, SDL_Rect& r);

	/** */
	~SDLLineEdit();

	void LoadThemeStyle(const char* widgettype);

	/** */
	void LoadThemeStyle(const char* widgettype, const char* objectname);

	/** start edit */
	void EditBegin();

	/** */
	void EditEnd();

	/** */
	void SetCursorPos(int p);

	/** */
	int GetCursorPos();

	/** */
	char* GetText();

	/** */
	void SetText(char* new_text);

#ifndef SWIG
	/** Sets formated text (like printf)*/
	void SetTextFormat(char* text, ...);
#endif

	/** */
	bool IsCursorVisible();

	/**
	Send a char into the LineEdit widget

	@param	c		the character to insert
	*/
	void SendChar(char c);

	/**
	Send a 'del' keystroke into the LineEdit widget
	*/
	void SendDel();

	/**
	Send a 'BKSPC' keystroke into the LineEdit widget
	*/
	void SendBackspace();

	/**
	Define a set of valid keys

	@param	keys		a string which contains all valid chars
	*/
	void SetValidKeys(char* keys);

protected:

	/** */
	virtual void eventEditBegin(int id, SDLWidget* widget, unsigned long data, void *clientdata);

	/** */
	virtual void eventEditEnd(int id, SDLWidget* widget, unsigned long data, void *clientdata);

	/** */
	void eventDraw(SDL_Surface* surface, SDL_Rect* rect);

	/** */
	bool eventKeyDown(const SDL_KeyboardEvent* key);

	/** */
	bool eventMouseButtonDown(const SDL_MouseButtonEvent* button);

	/** */
	void eventInputFocusLost(SDLMessageObject* newfocus);

	/** */
	bool eventFilterKey(const SDL_KeyboardEvent* key);

private:

	SDLLineEdit(const SDLLineEdit&);
	SDLLineEdit& operator=(SDLLineEdit&);

	void DrawText(SDL_Surface* surface, SDL_Rect* rect);
	void DrawTextCursor(SDL_Surface* surface, SDL_Rect* rect);
	int GetCursorXPos();
	char* GetDrawText();
	int GetCursorPosFromScreen(int x, int y);

	void InsertChar(char* c);
	void DeleteChar(Uint16 pos);

	void FreeValidKeys();
	bool IsValidKey(char c);

	char my_text[256];
	int my_cursorPosition;
	bool my_isCursorVisible;
	int my_offsetX;
	char* my_validkeys;

	SDL_Surface* my_srfTextCursor;

	//SDL_Color my_colorText;
};

#endif // SDL_LINEEDIT
