/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/17 18:22:47 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdlradiobutton.h,v $
    CVS/RCS Revision: $Revision: 1.20 $
    Status:           $State: Exp $
*/

#ifndef SDLRADIOBUTTON_H
#define SDLRADIOBUTTON_H

#ifdef SWIG
%include "swigcommon.h"
%module sdlradiobutton
%{
#include "sdlradiobutton.h"
%}
#endif

#include "sdlgradientwidget.h"
#include "sdlbutton.h"
#include "sdllabel.h"

/**
	@author Alexander Pipelka

	@short A single radio button.

	A single radio button, which has an attribute to signify what group
	it belongs to.
*/
/* Perhaps radio buttons should have a special SDLRadioButtonGroup parent class
 * to make things more clear and eliminate all the group stuff within the radio
 * button itself?
 *
 * NO :)
 * I think this kind of implementation is simple and easy to understand. 
 */
class DECLSPEC SDLRadioButton : public SDLGradientWidget  {
public:

	/** */
	SDLRadioButton(SDLWidget* parent, int id, SDL_Rect& r, char* text, SDLRadioButton* firstOfGroup = NULL);

	/** */
	~SDLRadioButton();

	void LoadThemeStyle(const char* widgettype);

	/** */
	bool GetPressed();

	/** */
	void SetPressed();

#ifndef SWIG
	/** Sets formated text (like printf)*/
	void SetTextFormat(char* text, ...);
#endif

	/** */
	void SetText(char* text);

	/** */
	char* GetText();

protected:

	/** */
	void AddToGroup(SDLRadioButton* w);

	/** */
	void ReleaseButton();

	/** */
	void eventMouseEnter();

	/** */
	void eventMouseLeave();

	/** */
	bool eventMouseButtonUp(const SDL_MouseButtonEvent* button);

	/** */
	bool eventButtonClick(int id, SDLWidget* widget);

	SDLRadioButton* my_groupFirst;
	SDLRadioButton* my_groupNext;

	SDLButton* my_widgetButton;
	SDLLabel* my_widgetLabel;
	bool my_isPressed;

private:
	SDLRadioButton(const SDLRadioButton&);
	SDLRadioButton& operator=(const SDLRadioButton&);

	bool my_storeMarker;

};

#endif // SDLRADIOBUTTON_H
