/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/25 16:13:38 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdlscrollbar.h,v $
    CVS/RCS Revision: $Revision: 1.24 $
    Status:           $State: Exp $
*/

#ifndef SDLSCROLLBAR_H
#define SDLSCROLLBAR_H

#ifdef SWIG
%include "swigcommon.h"
%module sdlscrollbar
%{
#include "sdlscrollbar.h"
%}
#endif

#include "sdlwidget.h"
#include "sdlbutton.h"
#include "sdlgradientwidget.h"

/**
	@author Alexander Pipelka

	@short A vertical or horizontal scrollbar

	Doesn't actually tie itself to any object to be scrolled, just get's told
	it's current state through function calls.
*/

class DECLSPEC SDLScrollBar : public SDLGradientWidget  {

protected:

#ifndef SWIG
class ScrollButton : public SDLButton {
public:

		ScrollButton(SDLScrollBar* parent, int id, SDL_Rect& r);
		virtual ~ScrollButton();

		void SetTickMode(bool on);

protected:

		/**  */
		bool eventMouseButtonDown(const SDL_MouseButtonEvent* button);
		/**  */
		bool eventMouseMotion(const SDL_MouseMotionEvent* motion);
		/**  */
		SDLScrollBar* GetParent();
		/**  */
		bool eventMouseButtonUp(const SDL_MouseButtonEvent* button);
		/**  */
		int GetPosFromPoint(SDL_Point p);

private:

		/**  */
		SDL_Point offset;

		/** */
		bool my_tickMode;

		int my_tempPos;
	};
#endif		// SWIG


public:

	/**  */
	SDLScrollBar(SDLWidget* parent, int id, SDL_Rect& r, int direction = SDL_SB_VERTICAL);

	/**  */
	virtual ~SDLScrollBar();

	void LoadThemeStyle(const char* widgettype);

	/**  */
	void SetPosition(Uint32 pos);

	/**  */
	int GetPosition();

	/**  */
	void SetWindowSize(Uint32 wsize);

	/**  */
	void SetRange(Uint32 min, Uint32 max);

	/**  */
	void SetLineSize(int ls);

protected:

	/**  */
	void eventSizeWindow(int w, int h);

	/**  */
	bool eventMouseMotion(const SDL_MouseMotionEvent* motion);

	/**  */
	bool eventMouseButtonDown(const SDL_MouseButtonEvent* button);

	/**  */
	bool eventButtonClick(int id, SDLWidget* widget);

	/**  */
	bool eventMouseButtonUp(const SDL_MouseButtonEvent* button);

	Uint32 scroll_min;
	Uint32 scroll_max;
	Uint32 scroll_current;
	Uint32 my_linesize;
	Uint32 my_pagesize;

	//int scroll_windowsize;

	SDLButton* scrollbutton[2];
	ScrollButton* dragbutton;
	SDL_Rect position[4];

	int sb_direction;
	int id;

	friend class ScrollButton;

private:

	SDLScrollBar(const SDLScrollBar&);
	SDLScrollBar& operator=(SDLScrollBar&);

};

#endif // SDLSCROLLBAR_H
