/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2000/11/15 11:08:01 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdlwidgetdnd.h,v $
    CVS/RCS Revision: $Revision: 1.15 $
    Status:           $State: Exp $
*/

#ifndef SDLWIDGETDND_H
#define SDLWIDGETDND_H

#ifdef SWIG
%include "swigcommon.h"
%module sdlwidgetdnd
%{
#include "sdlwidgetdnd.h"
%}
#endif

#include "sdlwidget.h"

/**
	@author Alexander Pipelka

	@short Drag and drop handler.

	All classes that would ever require drag and drop functionality
	(esentially all widgets) derive from this (eventually). Handles both the
	sending and receiving of all DnD events.
*/

class DECLSPEC SDLWidgetDnD : public SDLWidget  {
public:

	SDLWidgetDnD(SDLWidget* parent, int dndID, SDL_Rect& r);
	~SDLWidgetDnD();

	/**  */
	bool GetDrop();

	/**  */
	bool GetDrag();

	/**  */
	void RemoveObjectDnD(SDLWidgetDnD* obj);

	/**  */
	void SetDrop(bool drop);

	/**  */
	void SetDrag(bool drag);

	/**  */
	void updateDragArea(SDL_Point pt, SDL_Surface* image);

	/**  */
	void drawDragArea(SDL_Point pt, SDL_Surface* image);

protected: // Protected methods

	/**  */
	SDLWidgetDnD* FindDropTarget(SDL_Point pt);

	/**  */
	bool eventMouseButtonDown(const SDL_MouseButtonEvent* button);

	/**  */
	bool eventMouseMotion(const SDL_MouseMotionEvent* motion);

	/**  */
	bool eventMouseButtonUp(const SDL_MouseButtonEvent* button);

	/**  */
	virtual bool AcceptDrop(SDLWidgetDnD* source, int dndID);

	/**  */
	virtual bool eventDragStart();

	/**  */
	virtual bool eventDragDrop(SDLWidgetDnD* source, int dndID);

	/**  */
	virtual bool eventDragCancel();

	/**  */
	virtual SDL_Surface* eventQueryDragImage();

	/**  */
	virtual SDL_Surface* eventQueryDropImage(SDL_Surface* dragimage = NULL);

	SDLWidgetDnD* dnd_next;
	static SDLWidgetDnD* dnd_objectlist;

private:

	/**  */
	void cacheDragArea(SDL_Point p);

	/**  */
	void restoreDragArea(SDL_Point p);

	/**  */
	void CheckCursorPos(int& x, int& y);

	/**  */
	void slideDragImage(SDL_Point start, SDL_Point end, int steps, SDL_Surface* image);

	bool		CanDrag;
	bool		CanDrop;
	bool		Draging;
	SDL_Point dragPointStart;
	SDL_Point dragPointOld;
	SDL_Point dragPointCurrent;
	SDL_Surface* dragimage;
	SDL_Surface* dragimagecache;

private: // disable the copy operators
	SDLWidgetDnD(const SDLWidgetDnD&);
	SDLWidgetDnD& operator=(const SDLWidgetDnD&);
};

#endif // SDLWIDGETDND_H
