/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/18 18:11:06 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdlwidgetlist.h,v $
    CVS/RCS Revision: $Revision: 1.26 $
    Status:           $State: Exp $
*/

#ifndef SDLWIDGETLIST_H
#define SDLWIDGETLIST_H

#ifdef SWIG
%include "swigcommon.h"
%module sdlwidgetlist
%{
#include "sdlwidgetlist.h"
%}
#endif

#include "sdlgradientwidget.h"
#include "sdlscrollbar.h"

#include <vector>

/**
	@author Alexander Pipelka

	@short A group of widgets arranged in a specific way graphically

	Generally used to make a large 'pane' of widgets that can be scrolled
	through in a smaller 'portal' with scrollbars.
*/

class DECLSPEC SDLWidgetList : public SDLGradientWidget  {
public:

	/**
	Constructor of the SDLWidget class
	*/
	SDLWidgetList(SDLWidget* parent, SDL_Rect& r);

	/**
	Destructor of the SDLWidget class
	*/
	~SDLWidgetList();

	/**
	Add a widget to the list

	@param	w			pointer to a widget
	*/
	void AddWidget(SDLWidget* w);

	/**
	Remove a widget from the list

	@param	w			pointer to a widget
	*/
	bool RemoveWidget(SDLWidget* w);

	/**
	Find a widget by a given index

	@param	index		index of the widget to find
	@return					pointer to the widget
	*/
	SDLWidget* FindWidget(int index);

	/**
	Remove all widgets from the list (without deletion)
	*/
	void RemoveAll();

	/**
	Delete (destroy) all widgets in the list
	*/
	void DeleteAll();

	/**
	Get the number of widgets in the list
	*/
	int GetWidgetCount();

protected:

	/**  */
	void eventShow();

	/**  */
	void eventSizeWindow(int w, int h);
	
	/**  */
	bool eventScrollPos(int id, SDLWidget* widget, unsigned long data);

	/**  */
	bool eventScrollTrack(int id, SDLWidget* widget, unsigned long data);

	/**  */
	void ScrollToY(Sint32 position);

	/**
	Search for a widget at a given y-position

	@param	y			the position
	@return				pointer to the widget or NULL
	*/
	SDLWidget* GetWidgetFromPos(Sint32 y);

	SDLScrollBar* my_objScrollbar;

	SDL_Rect my_rectScrollbar;
	SDL_Rect my_rectList;

	int my_widthScrollbar;

	/** swig doesn't understand vectors... */
#ifndef SWIG
	std::vector < SDLWidget* > my_widgetList; // Hmmm, I know about this: vector :))
#endif
	
	int my_widgetCount;
	int my_firstWidget;
	Uint32 my_height;

private:

	SDLWidgetList(const SDLWidgetList&);
	SDLWidgetList& operator=(const SDLWidgetList&);

};

#endif // SDLWIDGETLIST_H
