/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000  Alexander Pipelka
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
    Alexander Pipelka
    pipelka@teleweb.at
 
    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/01/17 18:22:47 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/src/sdlwindow.h,v $
    CVS/RCS Revision: $Revision: 1.16 $
    Status:           $State: Exp $
*/

#ifndef SDLWINDOW_H
#define SDLWINDOW_H

#ifdef SWIG
%include "swigcommon.h"
%module sdlwindow
%{
#include "sdlwindow.h"
%}
#endif

#include "sdlgradientwidget.h"
#include "sdlbutton.h"

/**
	@author Alexander Pipelka

	@short A window inside the program (not a windowing environment window)

	Creates a small 'fake' window entirely inside ParaGUI (ie has a ParaGUI
	widget as a parent)
*/
/* Should this even exist? It would be much better for people to create a whole
 * new 'real' window, than little fake ones that can't be moves from the current
 * window (and move really slowly too :) ). Non-window-manager environments
 * may have to be considered though :/
 */

class DECLSPEC SDLWindow : public SDLGradientWidget  {
public:
	
	/** */
	SDLWindow(SDLWidget* parent, SDL_Rect& r, char* windowtext);
	
	/** */
	~SDLWindow();

	void LoadThemeStyle(const char* widgettype);

	void SetColorTitlebar(Uint32 color);
	
protected:

	/** */
	void eventDraw(SDL_Surface* surface, SDL_Rect* rect);
	
	/** */
	void eventSizeWindow(int w, int h);
	
	/** */
	bool eventButtonClick(int id, SDLWidget* widget);

	/** */
	bool eventMouseButtonDown(const SDL_MouseButtonEvent* button);

	/** */
	bool eventMouseButtonUp(const SDL_MouseButtonEvent* button);
	
	/** */
	bool eventMouseMotion(const SDL_MouseMotionEvent* motion);

private:

	SDL_Rect my_rectTitlebar;
	SDL_Surface* my_srfTitlebar;
	SDL_Gradient my_gradientTitlebar;
	SDL_Color my_colorTitlebar;
	char my_text[255];
	Uint8 my_heightTitlebar;
	SDL_Surface* my_backgroundTitlebar;
	int my_backmodeTitlebar;
	int my_blendTitlebar;
	int my_bordersizeTitlebar;
	
	SDLButton* my_buttonClose;
	bool my_moveMode;
	Uint8 my_moveTransparency;
	SDL_Point my_moveDelta;

private: // disable the copy operators
	SDLWindow(const SDLWindow&);
	SDLWindow& operator=(const SDLWindow&);
};

#endif // SDLWINDOW_H
